@@ -43,18 +43,11 @@ use super::props::{CANVAS_X_BOUNDS, CANVAS_Y_BOUNDS};
 /// ## Canvas
 ///
 /// The Canvas widget may be used to draw more detailed figures using braille patterns (each cell can have a braille character in 8 different positions).
+#[derive(Default)]
 pub struct Canvas {
     props: Props,
 }
 
-impl Default for Canvas {
-    fn default() -> Self {
-        Self {
-            props: Props::default(),
-        }
-    }
-}
-
 impl Canvas {
     pub fn foreground(mut self, fg: Color) -> Self {
         self.attr(Attribute::Foreground, AttrValue::Color(fg));
