@@ -41,22 +41,13 @@ use tuirealm::{Frame, MockComponent, State, StateValue};
 /// ## CheckboxStates
 ///
 /// CheckboxStates contains states for this component
+#[derive(Default)]
 pub struct CheckboxStates {
     pub choice: usize,         // Selected option
     pub choices: Vec<String>,  // Available choices
     pub selection: Vec<usize>, // Selected options
 }
 
-impl Default for CheckboxStates {
-    fn default() -> Self {
-        CheckboxStates {
-            choice: 0,
-            choices: Vec::new(),
-            selection: Vec::new(),
-        }
-    }
-}
-
 impl CheckboxStates {
     /// ### next_choice
     ///
@@ -130,20 +121,12 @@ impl CheckboxStates {
 /// ## Checkbox
 ///
 /// Checkbox component represents a group of tabs to select from
+#[derive(Default)]
 pub struct Checkbox {
     props: Props,
     pub states: CheckboxStates,
 }
 
-impl Default for Checkbox {
-    fn default() -> Self {
-        Self {
-            props: Props::default(),
-            states: CheckboxStates::default(),
-        }
-    }
-}
-
 impl Checkbox {
     pub fn foreground(mut self, fg: Color) -> Self {
         self.attr(Attribute::Foreground, AttrValue::Color(fg));
