@@ -35,18 +35,11 @@ use tuirealm::{Frame, MockComponent, State};
 /// ## Label
 ///
 /// represents a read-only text component without any container.
+#[derive(Default)]
 pub struct Label {
     props: Props,
 }
 
-impl Default for Label {
-    fn default() -> Self {
-        Self {
-            props: Props::default(),
-        }
-    }
-}
-
 impl Label {
     pub fn foreground(mut self, fg: Color) -> Self {
         self.attr(Attribute::Foreground, AttrValue::Color(fg));
