@@ -46,18 +46,11 @@ use tuirealm::{Frame, MockComponent, State};
 /// ## Paragraph
 ///
 /// represents a read-only text component without any container.
+#[derive(Default)]
 pub struct Paragraph {
     props: Props,
 }
 
-impl Default for Paragraph {
-    fn default() -> Self {
-        Self {
-            props: Props::default(),
-        }
-    }
-}
-
 impl Paragraph {
     pub fn foreground(mut self, fg: Color) -> Self {
         self.attr(Attribute::Foreground, AttrValue::Color(fg));
