@@ -43,22 +43,13 @@ use tuirealm::{Frame, MockComponent, State, StateValue};
 /// ## SelectStates
 ///
 /// Component states
+#[derive(Default)]
 pub struct SelectStates {
     pub choices: Vec<String>, // Available choices
     pub selected: usize,
     pub tab_open: bool,
 }
 
-impl Default for SelectStates {
-    fn default() -> Self {
-        Self {
-            choices: Vec::new(),
-            selected: 0,
-            tab_open: false,
-        }
-    }
-}
-
 impl SelectStates {
     /// ### next_choice
     ///
@@ -132,22 +123,13 @@ impl SelectStates {
 
 // -- component
 
+#[derive(Default)]
 pub struct Select {
     props: Props,
     pub states: SelectStates,
     hg_str: Option<String>, // CRAP CRAP CRAP
 }
 
-impl Default for Select {
-    fn default() -> Self {
-        Self {
-            props: Props::default(),
-            states: SelectStates::default(),
-            hg_str: None,
-        }
-    }
-}
-
 impl Select {
     pub fn foreground(mut self, fg: Color) -> Self {
         self.attr(Attribute::Foreground, AttrValue::Color(fg));
