@@ -43,18 +43,11 @@ use tuirealm::{Frame, MockComponent, State};
 /// ## Span
 ///
 /// represents a read-only text component without any container, but with multy-style text parts
+#[derive(Default)]
 pub struct Span {
     props: Props,
 }
 
-impl Default for Span {
-    fn default() -> Self {
-        Self {
-            props: Props::default(),
-        }
-    }
-}
-
 impl Span {
     pub fn foreground(mut self, fg: Color) -> Self {
         self.attr(Attribute::Foreground, AttrValue::Color(fg));
