@@ -37,18 +37,11 @@ use tuirealm::{Frame, MockComponent, State};
 /// ## Sparkline
 ///
 /// A sparkline over more lines
+#[derive(Default)]
 pub struct Sparkline {
     props: Props,
 }
 
-impl Default for Sparkline {
-    fn default() -> Self {
-        Self {
-            props: Props::default(),
-        }
-    }
-}
-
 impl Sparkline {
     pub fn foreground(mut self, fg: Color) -> Self {
         self.attr(Attribute::Foreground, AttrValue::Color(fg));
