@@ -36,20 +36,12 @@ use tuirealm::{Frame, MockComponent, State};
 
 // -- states
 
+#[derive(Default)]
 pub struct SpinnerStates {
     pub sequence: Vec<char>,
     pub step: usize,
 }
 
-impl Default for SpinnerStates {
-    fn default() -> Self {
-        Self {
-            sequence: Vec::default(),
-            step: 0,
-        }
-    }
-}
-
 impl SpinnerStates {
     /// ### reset
     ///
@@ -79,20 +71,12 @@ impl SpinnerStates {
 /// ## Spinner
 ///
 /// A textual spinner which step changes at each `view()` call
+#[derive(Default)]
 pub struct Spinner {
     props: Props,
     pub states: SpinnerStates,
 }
 
-impl Default for Spinner {
-    fn default() -> Self {
-        Self {
-            props: Props::default(),
-            states: SpinnerStates::default(),
-        }
-    }
-}
-
 impl Spinner {
     pub fn foreground(mut self, fg: Color) -> Self {
         self.attr(Attribute::Foreground, AttrValue::Color(fg));
